# -*- coding: utf-8 -*-
"""
Created on Wed Jun 26 11:10:43 2019

@auteur : Louis-Philippe Baillargeon
"""

import numpy as np

#%%deal with weird pixels
def findWeirdPixels(X, nb_etype = 6):
    
    medians = np.median(X, axis = 0)    # median for each energy level
    stds = np.std(X, axis = 0)          # standart deviation for each energy level
    maxval = medians + stds*nb_etype
    
    weirdmap = np.where(X>maxval, 1,0)
    
    weirdlevint = np.where(weirdmap == 1)
    weirdlev = np.array([weirdlevint[0],weirdlevint[1]]).T

    
    return weirdlev, weirdmap



#estimate weird pixels
def estimateWeirdPixelsList(X, weirdlev, weirdmap, neighbours = 3):
# X : spectra in form [pix,lev]
# weirlev : list of weird levels in form [#pix,#lev]
# neighbours : number of pixels used on each side to estimate the value of the weird level
    
    
    
    nb_level = len(X[0,:]) 

    for i in range(len(weirdlev[:,0])):
        
        
            pix = weirdlev[i,0]
            lev = weirdlev[i,1]
            
            xestime = 0                    # initialisation du xestimé
            k = 1                          # compteur
            nb_neighbours = 0              # total valid neigbours
            
            
            while(k < np.amin([nb_level-lev, neighbours+1])):              # onfait la moyenne des 3 niveaux suivants sauf si on est au bout 
                
                if(weirdmap[pix, lev+k] == 0):                            # ou qu'ils sont fautifs
                           
                    xestime = xestime + X[pix, lev+k]
                    
                    nb_neighbours = nb_neighbours+1
                k = k+1
    
        
    
             
            k = 1                          # compteur
            while k < np.amin([lev,neighbours+1]):                        # et des 3 niveaux précedents sauf si on est au début
               
                xestime = xestime + X[pix, lev-k]
                nb_neighbours = nb_neighbours+1
                k = k+1
            

            if nb_neighbours > 0:
                X[pix,lev] = xestime/nb_neighbours
                
            else:
                print('warning, estimation might be less precised due to too corrupted data')
                X[pix,lev] = estimateWeirdPixel(X, pix, lev, weirdmap, nb_neighbours, nb_neighbours*5)


    return X



def estimateWeirdPixel(X, pix, lev, weirdmap, prev_neighbours, next_neighbours):
    
    xestime = 0                    # initialisation du xestimé
    k = prev_neighbours+1          # compteur
    nb_neighbours = 0              # total valid neigbours
    nb_level = len(X[0,:]) 
    nb_pix = len(X[:,0])
    
    
    while(k < np.amin([nb_level-lev, next_neighbours+1])):              # on fait la moyenne des 3*5 niveaux suivants sauf si on est au bout 
        
        if(weirdmap[pix, lev+k] == 0):                                  # ou qu'ils sont fautifs
                   
            xestime = xestime + X[pix, lev+k]
            
            nb_neighbours = nb_neighbours+1
        k = k+1



     
    k = prev_neighbours+1                          # compteur
    while k < np.amin([lev,next_neighbours+1]):                        # et des 3 niveaux précedents sauf si on est au début
       
        xestime = xestime + X[pix, lev-k]
        nb_neighbours = nb_neighbours+1
        k = k+1
        
        
        
    if nb_neighbours > 0:
        x = xestime/nb_neighbours
        
    else:
        
        x = 1/nb_pix
        print('warning : one pixel is really corrupted, some levels could not be guessed and have been flatened')
        
    return x
  
    
    




                 


# -*- coding: utf-8 -*-
"""
Created on Fri Sep 21 15:28:17 2018

@author: cauh2701
"""

import numpy as np
from sklearn.decomposition import NMF
from SI_File_Toolbox import normalize


class HyperspectralSegmentation_NMF:
    def nmf(xraw, nb_c, init, nb_iter = 25):
        
        x = normalize(xraw)
        model = NMF(n_components=nb_c, max_iter=nb_iter, init='random', random_state=0)
        s = model.fit_transform(x.T)
        
        x_sum = np.asarray([np.sum(x, axis=1)]).T
        x_norm = x / x_sum
        
        s = s.T
        c = x_norm @ s.T @ np.linalg.inv(s @ s.T)
        return c, s


# -*- coding: utf-8 -*-
'''
@auteurs : Louis-Philippe Baillargeon et Hugo Caussan
'''
#%% User Input


# SET THE PARAMETERS

#paramètres d'affichage
Emin = 490.234                  # énergie du niveau 0 eV
Emax = 591.885                  # énergie du niveau max eV
Ppas = 1                        # distance entre les pixels (nm)

#file parameters
path = 'data_2.txt'             # choose your file
dim = 2                         # 2D or 3D file
nb_c = 3                       # Number of components

#analysis parameters - general
Bin = False                     # Bin the data
correctPix = False              # Enable the cosmic Xray filter, only works with sufficient dwell time
nb_etype = 3                    # Criteria for cosmic Xray


#analysis parameters - hiearchical init
nb_imcr = 1                     # Number of itteration of mcrllm in hierarchical
min_pixels = 1                  # Minimum of pixel in a division (should be about one percent of total pixels)
max_pixels = 10                 # Maximum of pixels in a division (should be 3 to 10 times bigger than min pixels)
Max_level = 40                  # Maximum of subdivision



#%% Code

# imports
import numpy as np
from h_MCR_LLM_Python import h_MCR_LLM
from SI_File_Toolbox import loadFile, dataBin, normalize
from cosmicRays import findWeirdPixels, estimateWeirdPixelsList
import pcaselect

# LOAD THE DATA

print("load data")  

X3 = loadFile(path)
if dim == 3:
    dim1 = X3.shape[0]
    dim2 = X3.shape[1]
    nb_level = X3.shape[2]
    nb_pix = dim1*dim2
    
    
elif dim == 2:
    nb_level = X3.shape[1]
    nb_pix = X3.shape[0]




X = np.reshape(X3, (nb_pix, nb_level))
        

# Bin the data set
        
if Bin:
    print("\nbin data :")     
    X = dataBin(X, 2)

        

# Bin the data set
        
if Bin:
    print("\nbin data :")     
    X = dataBin(X3, Bin)





# Deal with weird pixels
# Finds the corrputed by Xray energy levels of a pixel by comparing it to the same levels of other pixels. If its too large, it is approximated by an average of its neigbours
# Only works with high count data
    
if correctPix:
    print("\nDeal with weird pixels:")     
    Xtrash = np.copy(X)
    
    print("\nfind weird pixels:")    
    weirdlev, weirdmap = findWeirdPixels(np.copy(X), nb_etype)

    
    print("\nestimate weird pixels:")    #partie un peu longue, pourrait améliorer   
    X = estimateWeirdPixelsList(np.copy(X), weirdlev, weirdmap, neighbours = 5)

Xraw = np.copy(X)


#avoid errors, if a energy level has 0 counts on all pixels, it causes log(0) and the level is meaningless, so we take it out
deletedLevels = []
nb_deleted = 0

for lev in range(nb_level):
    
    if np.sum(Xraw[:,lev-nb_deleted]) <= 0:
        
        deletedLevels.append(lev)
        Xraw = np.delete(Xraw, lev-nb_deleted, axis = 1)
        nb_deleted = nb_deleted + 1







# START THE RUN


# Run h_MCR_LLM (might take alot of time)
print("MCR hiérachique jusqu'à " + str(Max_level) + " niveaux - min_pixels = " + str(min_pixels) + " :\n")
S_hier = h_MCR_LLM.h_mcr_llm(nb_imcr, min_pixels, max_pixels, Max_level, Xraw)

np.save('S_hier.npy', S_hier)




print("\nPCA :")                    

Sselect = pcaselect.computeShow(S_hier, nb_c, Emin = Emin, Emax = Emax)










# -*- coding: utf-8 -*-
"""
Created on Thu Aug 15 13:35:05 2019

@auteur : Louis-Philippe Baillargeon
"""
#%% User input

# User input is set in Run h_MCR_LLM, just make sure that you don't delete your variables automatically when you run the script 
# in Run/Configuration per file/General Settings/Remove all variales before execution ; must be unchecked



#%% PCA of h_MCR results - choose spectrum

#loads
import numpy as np
import pcaselect


S_hier = np.load('S_hier.npy')

Sselect = pcaselect.computeSelect(S_hier, nb_c)





from mcrllm.AllTools import *
from mcrllm.cosmicRays import *
from mcrllm.Demi_LLM_Python import *
from mcrllm.dm4 import *
from mcrllm.fct_MCRALS import *
from mcrllm.fct_MCRLLM import *
from mcrllm.NMF import *
from mcrllm.PureSpecies import *
from mcrllm.GUI_support import *
from mcrllm.h_MCR_LLM_Python import *
from mcrllm.init import *
from mcrllm.pcaselect import *
from mcrllm.Run GUI import *
from mcrllm.Run h_MCR_LLM-1 import *
from mcrllm.Run h_MCR_LLM-2 import *
from mcrllm.Run h_MCR_LLM-3 (demi LLM) import *
from mcrllm.Run h_MCR_LLM-3 (full LLM) import *
from mcrllm.Run MCR_LLM import *
from mcrllm.SI_File_Toolbox import *


# -*- coding: utf-8 -*-
"""
Created on Fri Jun 28 11:32:50 2019

@author: Louis-Philippe Baillargeon
"""

import numpy as np
from sklearn import decomposition
from PointSelector import SelectFromCollection
from SI_File_Toolbox import plotSpectra


def computeShow(S_hier, nb_c, Emin = 0, Emax = 20):
#Computes the PCA and opens the windows to select wanted spectra
    
    #substract mean for pca
    Smoy = np.mean(S_hier, axis = 1)
    S_centered = S_hier.T-Smoy
    S_centered = S_centered.T
    
    #pca transformation
    pca = decomposition.PCA(n_components=nb_c)
    pca.fit(S_centered)
    
    components = pca.components_
    plotSpectra(components, Emin = Emin, Emax = Emax, title = 'Principal Component', ylabel = 'score')
    
    return 


def computeSelect(S_hier, nb_c):
#Computes the PCA and opens the windows to select wanted spectra
    
    #substract mean for pca
    Smoy = np.mean(S_hier, axis = 1)
    S_centered = S_hier.T-Smoy
    S_centered = S_centered.T
    
    #pca transformation
    pca = decomposition.PCA(n_components=nb_c)
    pca.fit(S_centered)
    
    Spca = pca.transform(S_centered)  # spectra expressed in principal components
    
    Sselect = [SelectFromCollection(Spca, S_hier)   for i in range(nb_c)]
    
    return Sselect
    




# -*- coding: utf-8 -*-
"""
Created on Wed Sep 19 10:10:16 2018
@author: cauh2701
"""
#from fct_MCRLLM import HyperspectralSegmentation_MCR_LLM
#from fct_MCRALS import HyperspectralSegmentation_MCR_ALS

#from init import *
#from tkinter import *
from tkinter.messagebox import showerror
from SI_File_Toolbox import loadFile, dataBin, normalize
import matplotlib.pyplot as plt
import numpy as np
from skimage.transform import resize
import dm4
import scipy.io as sc

def run(initList, fctList, nb_c, nb_iter, filepath, nb_dim, hier):
    for i in range(50):
        print("\n")
    
        
    x = loadFile(filepath)
        
   
    try:
        if nb_dim == 3:
        
            # resize image
            print(x.shape)  
            s0 = x.shape[0]
            s1 = x.shape[1]
            s2 = x.shape[2]
                
            nb_pix = s0*s1
        
            x = np.reshape(x, (nb_pix, s2))
            print('Image has been resized.')
            print(x.shape)
            
        elif nb_dim == 2:
            
            # resize image
            print(x.shape)  
            s0 = x.shape[0]
            s2 = x.shape[1]
            
        
            x = np.reshape(x, (s0, s2))
            print('Image has been resized.')
            print(x.shape)
        else:
            raise ValueError

    except ValueError:
        showerror('Erreur', 'Veuillez choisir un nombre de dimensions valide')
        return



    
    xraw = np.copy(x)
    
    #avoid errors, if a energy level has 0 counts on all pixels, it causes log(0) and the level is meaningless, so we take it out
    deletedLevels = []
    nb_deleted = 0
    
    for lev in range(s2):
        
        if np.sum(xraw[:,lev-nb_deleted]) <= 0:
            
            deletedLevels.append(lev)
            xraw = np.delete(xraw, lev-nb_deleted, axis = 1)
            nb_deleted = nb_deleted + 1
    
    
    # normalize data
    x = normalize(xraw)

    for i in initList:
        if i.trigger:
            su = i.do(x, nb_c)#Appel de l'initialisation
            
            for f in fctList:
                if f.trigger:
                    print("{} - {}".format(f.nom, i.nom))
                    try:                    
                        [c, s] = f.do(xraw, nb_c, su, nb_iter = nb_iter)   #Appel de la fonction
                        C = np.array(c)
                        S = np.array(s)
                        
                        for ii in range(nb_deleted):  #Insert deleted spectra back (the spectra was 0 that's why we took it out)
                            S = np.insert(S,deletedLevels[ii], np.zeros(nb_c), axis = 1)
                    except ValueError:
                        print("Non compatibles...")
                        break
                    plt.figure("Spectre {} + {} / {} comp".format(f.nom, i.nom, nb_c))
                    leg = list()
                    

                    for iz in range(nb_c):
                        leg.append("Elem {}".format(iz+1))
                    
                    for n in range (nb_c):
                        plt.plot(S[n,:], linewidth = 0.7)
                    
                    plt.xlabel('Wavelength')
                    plt.ylabel('Spectra')
                    plt.title("{} - {}".format(f.nom, i.nom), fontsize=12)
                    plt.legend(leg)
                    
                    if not isinstance(c, int): # Si c'est n'est pas un int => C'est un array
                        
                        plt.figure("{} + {} / {} comp".format(f.nom, i.nom, nb_c))
                        
                        
                        if  nb_dim == 3:
                            
                            C = np.reshape(C, (s0, s1, nb_c))
                            for ic in range(nb_c):                        
                                a = 331+ic
                                plt.subplot(a); plt.imshow(C[:,:,ic])
                                plt.title("Elem {}".format(ic+1))
                                plt.colorbar()
                                
                                
                        elif nb_dim==2:
                            C = np.reshape(C, (s0, nb_c))
                            plt.title("Concentrations")
                            plt.xlabel('pixels')
                            plt.ylabel('abondance')
                            
                            for ic in range(nb_c):                        
                                plt.plot(C[:,ic])
                                
                    
                    
    if hier:      
    #Je ne savais pas comment appeler les fonctions d'initialisation et je n'avais pas le temps de l'apprendre, alors,
    #j'ai duck tapé ça un peu. Ça mériterait un clean up. On pourrait l'appeler comme les autres au lieu de la faire ici. Faut juste loader Sselect dans le fond
        su = np.load('Sselect.npy')
            
        for f in fctList:
            if f.trigger:
                print("{} - {}".format(f.nom, i.nom))
                try:                    
                    [c, s] = f.do(xraw, nb_c, su, nb_iter = nb_iter)   #Appel de la fonction
                    C = np.array(c)
                    S = np.array(s)
                    
                    for ii in range(nb_deleted):  #Insert deleted spectra back (the spectra was 0 that's why we took it out)
                        S = np.insert(S,deletedLevels[ii], np.zeros(nb_c), axis = 1)
                except ValueError:
                    print("Non compatibles...")
                    break
                plt.figure("Spectre {} + {} / {} comp".format(f.nom, i.nom, nb_c))
                leg = list()
                

                for iz in range(nb_c):
                    leg.append("Elem {}".format(iz+1))
                
                for n in range (nb_c):
                    plt.plot(S[n,:], linewidth = 0.7)
                
                plt.xlabel('Wavelength')
                plt.ylabel('Spectra')
                plt.title("{} - {}".format(f.nom, i.nom), fontsize=12)
                plt.legend(leg)
                
                if not isinstance(c, int): # Si c'est n'est pas un int => C'est un array
                    
                    plt.figure("{} + {} / {} comp".format(f.nom, i.nom, nb_c))
                    
                    
                    if  nb_dim == 3:
                        
                        C = np.reshape(C, (s0, s1, nb_c))
                        for ic in range(nb_c):                        
                            a = 331+ic
                            plt.subplot(a); plt.imshow(C[:,:,ic])
                            plt.title("Elem {}".format(ic+1))
                            plt.colorbar()
                            
                            
                    elif nb_dim==2:
                        C = np.reshape(C, (s0, nb_c))
                        plt.title("Concentrations")
                        plt.xlabel('pixels')
                        plt.ylabel('abondance')
                        
                        for ic in range(nb_c):                        
                            plt.plot(C[:,ic])
                                
                            
                    




# MCR ALS

"""
Coded by Jeffrey Byrns
Adapted by Ryan Gosselin
"""

# import packages
import numpy as np
from scipy import linalg
from SI_File_Toolbox import normalize

class HyperspectralSegmentation_MCR_ALS:
    
    @classmethod
    def mcr_als(cls,xraw, nb_c, init, nb_iter=50):  #I added xraw to facilitates call from GUI
        
        x = normalize(xraw)

        max_iter = nb_iter
        x_n = np.sum(x, 1)
        x_n[x_n < 0.025*np.max(x_n)] = np.max(x_n)
        x = x.T / x_n
        x = x.T
        x.astype('float64')

        '''
        
        
        Updates: 
        1 - The issue was that it the spectral images contained many pixels with low or no signal (except random 
        noise), therefore when normalizing, the amplitude of those pixels would overcome the amplitude of the pixels 
        that had a true signal. So to keep the shape of the data, the normalization is now done in relation with the 
        maximum area under the curve. That way, the area of the most intense pixel will be 1 and the other ones will 
        simply be less than 1.
        
        2- I cannot only use the maximum of the sum because normalizing does allow to amplify features of low signal
        pixels. So line 48 serve as a filter to apply standard normalisation on pixel having sum > 0.05*max(sum(x,1) and 
        divide by max(sum(x,1)) for the pixels that are just random noise.
        
        3- Turns out, the reason the matrix became singular, was because one of the spectra was all negative (and was 
        then contrained to 0). The result was that the sum of that spectrum was 0 and thus making the matrix singular. 
        Adding a break allows to stop the iteration before it happens.
        '''

        s = init

        cnt = 0
        flag = True

        while flag:
            s_mem = s

            # Concentrations by linear regression between X and S
            c1 = s @ s.T
            c2 = linalg.inv(c1)
            c3 = x @ s.T
            c = c3 @ c2

            c[c < 0] = 0
            c_sum = np.sum(c, 1) # Modification to C - Closure
            c_sum[c_sum == 0] = 1  # This line prevent any division by 0
            c = c.T / c_sum
            c = c.T


            # Spectra by linear regression between X and C
            s1 = c.T @ c
            s2 = linalg.inv(s1)
            s3 = c.T @ x
            s = s2 @ s3
            s[s < 0] = 0
            c_mem = c
            cnt = cnt + 1

            if cnt == max_iter or np.min(np.sum(s, 1)) == 0:
                if np.min(np.sum(s, 1)) == 0:
                    s = s_mem
                    c = c_mem
                flag = False


        c = c.astype('float32')
        s = s.astype('float32')

        return c, s


# -*- coding: utf-8 -*-
"""
@auteurs :  Hugo Caussan et Louis-Philippe Baillargeon
"""
import numpy as np
import matplotlib.pyplot as plt
from scipy.io import savemat
import dm4
import scipy.io as sc
import scipy.stats as st

#import pypng as png

"""Ce script contient des fonctions utiles pour travailler avec des spectres images""" 



# Sert à ouvrir les plots à l'exterieur de la console
try:
    import IPython
    shell = IPython.get_ipython()
    shell.enable_matplotlib(gui='qt')
except:
    pass

# Permet d'ouvrir un fichier dm3 / Mat / spd
def loadFile(filepath):

    if filepath[-4:]==".dm4":
        dm4data = dm4.DM4File.open(filepath)
        tags = dm4data.read_directory()
        image_data_tag = tags.named_subdirs['ImageList'].unnamed_subdirs[1].named_subdirs['ImageData']
        image_tag = image_data_tag.named_tags['Data']
        dim1 = dm4data.read_tag_data(image_data_tag.named_subdirs['Dimensions'].unnamed_tags[0])
        dim2 = dm4data.read_tag_data(image_data_tag.named_subdirs['Dimensions'].unnamed_tags[1])
        nb_level = dm4data.read_tag_data(image_data_tag.named_subdirs['Dimensions'].unnamed_tags[2])
        x = np.array(dm4data.read_tag_data(image_tag), dtype=np.uint16)
        x = np.reshape(x, (dim1,dim2,nb_level), order = 'F')    #shape the matrix like the data is stored
    
    elif filepath[-4:]==".mat":#Load a Mat file 
        Xdict = sc.loadmat(filepath)
        x = Xdict['image_round']
        
    elif filepath[-4:]==".txt":#Load a txt file 
        x = np.loadtxt(filepath, comments="#", delimiter=",", unpack=False).T
    
    elif filepath[-4:]==".spd": # SPD FILE (EDAX)
        h = open(filepath,'rb')
        header = {}
        header['tag'] = np.fromfile(h,'int8',16)
        header['version'] = np.fromfile(h,'int32',1)[0]
        header['nSpectra'] = np.fromfile(h,'int32',1)[0]
        header['nCols'] = np.fromfile(h,'int32',1)[0]
        header['nRows'] = np.fromfile(h,'int32',1)[0]
        header['nChannels'] = np.fromfile(h,'int32',1)[0]
        header['countBytes'] = np.fromfile(h,'int32',1)[0]
        header['dataOffset'] = np.fromfile(h,'int32',1)[0]
        header['nFrames'] = np.fromfile(h,'int32',1)[0]
        header['fName'] = np.fromfile(h,'int8',120)
        header['filler'] = np.fromfile(h,'int8',900)
        x = np.zeros([header['nSpectra'],header['nChannels']],'int16')
        for i in range(0,header['nSpectra']):
            x[i,:] = np.fromfile(h,'int16',header['nChannels'])
        h.close()
        x = np.float64(x)
        x = np.reshape(x,[header['nRows'],header['nCols'],header['nChannels']])
        
    elif filepath[-4:]==".npy": # SPD FILE (EDAX)
        x = np.load(filepath)
        
    else:
        print("Type de fichier "+filepath[-4:]+" non prix en charge")

    return x



# Pour normaliser un jeu de données
def normalize(x):
    
    x_sum = np.array([np.sum(x, axis=1)]).T
    x_norm = x / x_sum
    
    if np.any(x_norm != x_norm):
        
        eq = 1/len(x[0,:])
        x_norm = np.where(x_norm != x_norm, eq, x_norm)
        
    
        
    return x_norm



# Verify if a distribution is indeed poisson
def poissonVerify(X):
# X must be a np.array set of pixels of same specie of form [pix,lev]
    Xvar = np.var(X, axis = 0)
    Xmean = np.mean(X, axis = 0)
    slope, intercept, r_value, p_value, std_err = st.linregress(Xvar,Xmean)
    
    plt.figure()
    plt.xlabel('Variance', fontsize = 25)
    plt.ylabel('Mean', fontsize = 25)
    plt.plot(Xvar, Xmean)
    plt.plot()
    ax = plt.axes()
    x = np.linspace(0, np.max(Xvar), 1000)
    ax.plot(x, intercept + slope*x);
    
    print('slope : ' + str(slope))
    print('r : ' + str(r_value))
    
    return slope, r_value, intercept


    

# Permet de bin une image spectrale
def dataBin(x, n = 2):
    dim = len(x.shape)
    if dim == 2:
        s0 = x.shape[0]
        s0 = s0 - s0%n
        
        xb = np.zeros((int(s0/n), x.shape[1]))
        for i in range(n):
            f = range(i,s0,n)
            xb = xb + x[f,:]
        
    elif dim == 3:
        s0 = x.shape[0]
        s1 = x.shape[1]
        
        s0 = s0 - s0%n
        s1 = s1 - s1%n
        
        x = x[:s0,:s1,:]
        xb = np.zeros((int(s0/n),int(s1/n),x.shape[2]))
        
        for i in range(n):
            f1 = range(i,s0,n)
            for j in range(n):
                f2 = range(j,s1,n)
                xb = xb + x[f1,:,:][:,f2,:]
        
    return xb/(n**(dim-1))


# Generate everything but the data on a plot
def plotSpectraSetup(title, xlabel, ylabel):     
    plt.figure()           
    plt.title(title, fontsize = 25)
    plt.xlabel(xlabel, fontsize = 25)
    plt.ylabel(ylabel, fontsize = 25)
    plt.tick_params(axis='both',length=12,which='both',labelsize='large')
    plt.grid(True)

     
# Plot the spectra for all phases
def plotSpectra(S, Emin = 0, Emax = 20, title = 'Phase spectra', xlabel = 'eV', ylabel = 'Abundance (/1)'):
    x = np.linspace(Emin,Emax, S.shape[1])            
    for i in range (S.shape[0]):
            plotSpectraSetup(str(title)+ ' ' + str(i), str(xlabel), str(ylabel))
            plt.plot(x, S[i])
            
# Plot the spectra of a few phases on the same plot to facilitate comparison, group is a np array that contains the indices of the phases that are meant to be ploted together
def plotSpectraGroup(S, group, Emin = 0, Emax = 20):
    x = np.linspace(Emin,Emax, S.shape[1])       
    plotSpectraSetup("Multiple phase Spectra", "eV", "Abundance (%)")
    
    for i in range(len(group)):
        plt.plot(x, 100*S[group[i],:])
        

            
# Plot les cartes de concentration de toutes les phases only works with 3D
def Cmap(cf):

    for i in range(0, len(cf[0,0,:])):
        plt.figure()
        plt.title('Concentration de la phase '+str(i))
        plt.imshow(np.log(cf[:,:,i]))
        plt.show()

# Plot Cmaps and spectras on one page
# If log is set to true, log concentrations will be shown instead of concentrations. Usefull if contrast is small, but can create false impression of high differences.
def plotCompare(S, Emin, Emax, C, pas = 1, log = False, title  = 'Phase '):
    x = np.linspace(Emin,Emax, S.shape[1])  
    
    for i in range (S.shape[0]):

        plt.figure()
        
        #spectra
        plt.subplot(1,2,1)
        plt.xlabel('loss (eV)', fontsize = 25)
        plt.ylabel('abundance', fontsize = 25)
        plt.tick_params(axis='both',length=12,which='both',labelsize='large') 
        plt.plot(x, S[i,:], '-', lw=2)
        plt.title(title + str(i) + ' Spectra', fontsize = 25)
        plt.grid(True)
        
        
        #conc
        plt.subplot(1,2,2)
        plt.tick_params(axis='both',length=12,which='both',labelsize='large')
        
        if log:
            plt.imshow(np.log(C[:,:,i]), origin = 'lower')
            
        else:
            plt.imshow(C[:,:,i], origin = 'lower')
            
        plt.xlabel('pixels', fontsize = 25)
        plt.ylabel('pixels', fontsize = 25)
        plt.title(title + str(i) + ' concentration map', fontsize = 25)
        plt.grid(True)
        
        plt.show
        



# plot le spectre total (tous les niveaux d'énergie additionnés)          
def spectraMap(X3D):   #X3D sous forme[YDim,XDim,Elevel]
    X2D = np.sum(X3D, axis = 2)
    plt.figure()
    plt.title('Tout le spectre reçu')
    plt.imshow(np.log(X2D.T), origin = 'lower')
    plt.show()
    
    
def importMJdata(path):
#Fonction spécifique au données simulées EDX 10 pyramides, elles sont enregistrées sousla forme X3[nb_level, xdim, ydim]
    X3= loadFile(path)
    X3 = X3.T
    return X3

    
        


                
                
                
                
                
                

    


# -*- coding: utf-8 -*-
"""
@auteurs : Louis-Philippe Baillargeon et Hugo Caussan
"""
#%% User Input
from init import KmeansInit as ini                                  # Choose the initialization to use1
from fct_MCRLLM import HyperspectralSegmentation_MCR_LLM             # Import the algorithm to use


# SET THE PARAMETERS

#paramètres d'affichage
Emin = 490.234                  # énergie du niveau 0 eV
Emax = 591.885                  # énergie du niveau max eV
pas = 1                         # distance entre les pixels (nm)

#file parameters
path = 'data_2.txt'             # choose your file
dim = 2                         # 2D or 3D file
nb_c = 7                       # Number of components(phases)

#analysis parameters - general
Bin = False                     # Bin the data
correctPix = False              # Enable the cosmic Xray filter, only works with sufficient dwell time
nb_etype = 3                    # Criteria for cosmic Xray

#analysis parameters - mcrllm 
nb_i = 5                        # Number of iterations in mcr_llm



#%% Code
import numpy as np
from SI_File_Toolbox import loadFile, normalize, dataBin, plotCompare, plotSpectraGroup
from cosmicRays import findWeirdPixels, estimateWeirdPixelsList
import matplotlib.pyplot as plt


# LOAD THE DATA

print("load data")  

X3 = loadFile(path)
if dim == 3:
    dim1 = X3.shape[0]
    dim2 = X3.shape[1]
    nb_level = X3.shape[2]
    nb_pix = dim1*dim2
    
    
elif dim == 2:
    nb_level = X3.shape[1]
    nb_pix = X3.shape[0]




X = np.reshape(X3, (nb_pix, nb_level))
        

# Bin the data set
        
if Bin:
    print("\nbin data :")     
    X = dataBin(X, 2)


# Deal with weird pixels

# Finds the corrputed by Xray energy levels of a pixel by comparing it to the same levels of other pixels. If its too large, it is approximated by an average of its neigbours
# Only works with high count data
    
if correctPix:
    print("\nDeal with weird pixels:")     
    Xtrash = np.copy(X)
    
    print("\nfind weird pixels:")    
    weirdlev, weirdmap = findWeirdPixels(np.copy(X), nb_etype)

    
    print("\nestimate weird pixels:")    #partie un peu longue, pourrait améliorer   
    X = estimateWeirdPixelsList(np.copy(X), weirdlev, weirdmap, neighbours = 3)
    

#avoid errors, if a energy level has 0 counts on all pixels, it causes log(0) and the level is meaningless, so we take it out
deletedLevels = []
nb_deleted = 0

for lev in range(nb_level):
    
    if np.sum(X[:,lev-nb_deleted]) <= 0:
        
        deletedLevels.append(lev)
        X= np.delete(X, lev-nb_deleted, axis = 1)
        nb_deleted = nb_deleted + 1


# normalize data
Xraw = np.copy(X)
X = normalize(X)


#%% START THE RUN

print("Initialisation :")
Si = ini.initialisation(X, nb_c) # Initialisation



print("MCR LLM : " + str(nb_c) + " composantes - " + str(nb_i) +" itérations\n")
C, S = HyperspectralSegmentation_MCR_LLM.mcr_llm(Xraw, nb_c, Si, nb_i) # Algorithm


#%% Show the results
#Insert deleted spectra back (the spectra was 0 that's why we took it out)
for i in range(nb_deleted):
    S = np.insert(S,deletedLevels[i], np.zeros(nb_c), axis = 1)
    


#rearrange data
if dim == 3:
    C3 = np.reshape(C, (dim1,dim2, nb_c))
    C = np.copy(C3)
    plotCompare(S, Emin, Emax, C, pas = 1, log = False)
    
else:
    plt.figure()
    plt.plot(C)
    
plotSpectraGroup(S, np.arange(nb_c), Emin = Emin, Emax = Emax)




# -*- coding: utf-8 -*-
'''
@auteurs : Louis-Philippe Baillargeon 
'''

# imports
import numpy as np
from SI_File_Toolbox import loadFile
import matplotlib.pyplot as plt
from math import factorial



def pureSpecies4carres1Cercle(path):
        
        
    X3D = loadFile(path, dim = 3)


    # Select data
    group1 = np.arange(0,100)
    group2 = np.arange(150,250)
    group3 = np.arange(110,140)
    
    allPix = np.arange(0,256)
    
    
    X1 = np.delete(X3D, np.delete(allPix, group1), axis = 0)
    X1 = np.delete(X1, np.delete(allPix, group1), axis = 1)
    
    X2 = np.delete(X3D, np.delete(allPix, group2), axis = 0)
    X2 = np.delete(X2, np.delete(allPix, group1), axis = 1)
    
    X3 = np.delete(X3D, np.delete(allPix, group3), axis = 0)
    X3 = np.delete(X3, np.delete(allPix, group3), axis = 1)
    
    return X1,X2,X3


def pureSpectra(X, dim = 3):
#sum of spectra on all pixels. Pixels must be of same specie to obtain pure spectra
    
    if dim ==3:
        S = np.sum(np.sum(X, axis = 0), axis = 0)
        S = S/(X.shape[0]*X.shape[1])
        
    elif dim==2:
        S = np.sum(X,axis = 0)
        
    plt.figure()
    plt.plot(S)
    return(S)
    
    
    
    
def findModeX(X, mode):
    
    lev = np.array([])
    
    for level in range(len(X[0,0,:])):
        dis1 = np.reshape(X[:,:,level], X.shape[0]*X.shape[1])
        
        count = np.zeros(max(dis1))
        
        for cnt in range(max(dis1)):
            for pix in range(len(dis1)):
                if dis1[pix] == cnt:
                    count[cnt] = count[cnt] + 1
        
        count = count/sum(count)
        countMode = np.argmax(count)
        if countMode == mode:
            lev = np.append(lev, level)
            
    return lev
    
    
    
    
    
class distribution:
#compute the distribution of counts on given energy level for multiple pixels of same specie
    @classmethod
    def __init__(self, X, level, dim = 3, maxl = 0):
        
        
        self.maxl = np.max([np.max(X),maxl])
        
        if dim ==3:
            self.dis = np.reshape(X[:,:,level], X.shape[0]*X.shape[1])
            
        elif dim ==2:
            self.dis = X[:,level]
            
        elif dim ==1:
            self.dis = X
        
        self.count = np.zeros(self.maxl)
        self.xraw = np.arange(self.maxl)
        
        
        if np.max(self.dis) == 0:
            self.count[0] =len(self.dis)
            self.countMode = 0
            self.countMean = 0
            self.countNorm =np.zeros(self.maxl)
            
        else:
            
            for cnt in range(np.max(self.dis)):
                for pix in range(len(self.dis)):
                    if self.dis[pix] == cnt:
                        self.count[cnt] = self.count[cnt] + 1
                        
            
            
            self.countSum = np.sum(self.count)
            self.countNorm = np.zeros(self.maxl)
            self.countNorm[:np.max(self.dis)] = self.count[:np.max(self.dis)]/self.countSum
            self.countMode = np.argmax(self.count) 
            self.abundance = self.xraw/self.countSum
            self.x = np.linspace(0,np.max(self.abundance), len(self.xraw))
            countMean = 0
            for cnt in range(len(self.count)):
                countMean = countMean + self.count[cnt]*cnt
                
            self.countMean = countMean/self.countSum
            

def lookDist(espece, level):
    dis = distribution(espece, level, dim = 2)
    yPred = dis.countMean
    
    
    
    plt.figure()
    plt.title('distribution of level ' + str(level) + ', espèce pure 3 , 4 carrés un cercle, \n real mean = ' + str(dis.countMean) + ', yPred = ' + str(yPred),fontsize = 30)
    
    # poisson
    fact = np.array([factorial(dis.xraw[i]) for i in range(len(dis.xraw))])
    lik = np.divide(np.multiply(np.power(yPred, dis.xraw), np.exp(-yPred)), fact)
    plt.plot(dis.xraw, lik , 'b-', lw=5, alpha=0.6, label='poisson')
    

    # mean 
    plt.axvline(x=dis.countMean, label='real mean')
    
    # ypred
    plt.axvline(x=yPred, color = 'm', label='yPred')
    
    
    #dots
    plt.plot(dis.countNorm, 'ro',  label='sum of counts of each pixel of same specie on level ' + str(level))
    
    #legend
    plt.legend(bbox_to_anchor=(1, 1), loc=1, borderaxespad=0., fontsize = 30)
    plt.xlabel('counts', fontsize = 35)
    plt.ylabel('nb pixels', fontsize = 35)
        

        
        
        







#! /usr/bin/env python
#  -*- coding: latin-1 -*-
#
# GUI module generated by PAGE version 4.17
# In conjunction with Tcl version 8.6
#    Sep 20, 2018 12:17:44 PM EDT  platform: Windows NT
'''
Auteur : Hugo
'''

import sys
from AllTools import run
import numpy as np
import matplotlib.pyplot as plt
from init import *
from fct_MCRLLM import HyperspectralSegmentation_MCR_LLM
from fct_MCRALS import HyperspectralSegmentation_MCR_ALS
from fct_NMF import HyperspectralSegmentation_NMF
from SI_File_Toolbox import loadFile
import pcaselect
from h_MCR_LLM_Python import h_MCR_LLM
from PointSelector import SelectFromCollection

from tkinter.filedialog import *
import webbrowser

try:
    from Tkinter import *
except ImportError:
    from tkinter import *

try:
    import ttk
    py3 = False
except ImportError:
    import tkinter.ttk as ttk
    py3 = True
    
    
try:
    import IPython
    shell = IPython.get_ipython()
    shell.enable_matplotlib(gui='qt')
except:
    pass

class Action:
    def __init__(self, nom, typ, fonction, trigger = 0):
        self.nom = nom
        self.typ = typ
        self.do = fonction
        self.trigger = trigger

def set_Tk_var():
    
    
    global nb_level
    nb_level = IntVar()
    nb_level.set(0)
    
    
    global nb_imcr
    nb_imcr = IntVar()
    nb_imcr.set(1)
    global min_pixels
    min_pixels = IntVar()
    min_pixels.set(1)
    global max_pixels
    max_pixels = IntVar()
    max_pixels.set(40)
    global Max_level
    Max_level = IntVar()
    Max_level.set(50)
    global hier
    hier = IntVar()
    
    
    global KMeansT
    KMeansT = IntVar()
    global NFindrT
    NFindrT = IntVar()
    global MBKmeansT
    MBKmeansT = IntVar()
    global AtgpT
    AtgpT = IntVar()
    global FippiT
    FippiT = IntVar()
    global PpiT
    PpiT = IntVar()
    
    global LlmT
    LlmT = IntVar()
    global AlsT
    AlsT = IntVar()
    global NmfT
    NmfT= IntVar() 
    
    global nb_i
    nb_i = IntVar()
    nb_i.set(5)
    global nb_c
    nb_c = IntVar()
    nb_c.set(5)
    global nb_dim
    nb_dim = IntVar()
    nb_dim.set(3)
    
    global DimT
    DimT = IntVar()
    DimT.set(1)
    global dim1
    dim1 = IntVar()
    dim1.set(50)
    global dim2
    dim2= IntVar()
    dim2.set(50)
    global zDim
    zDim = IntVar()
    zDim.set(0)
    
    
    global filepath
    filepath = "Aucun fichier selectionné"

def init(top, gui, *args, **kwargs):
    global w, top_level, root
    w = gui
    top_level = top
    root = top

def destroy_window():
    # Function which closes the window.
    global top_level
    top_level.destroy()
    top_level = None

def vp_start_gui():
    '''Starting point when module is the main routine.'''
    global val, w, root
    root = Tk()
    set_Tk_var()
    top = New_Toplevel (root)
    init(root, top)
    root.mainloop()

w = None
def create_New_Toplevel(root, *args, **kwargs):
    '''Starting point when module is imported by another program.'''
    global w, w_win, rt
    rt = root
    w = Toplevel (root)
    set_Tk_var()
    top = New_Toplevel (w)
    init(w, top, *args, **kwargs)
    return (w, top)

def destroy_New_Toplevel():
    global w
    w.destroy()
    w = None




class New_Toplevel: 
    
    def returnValues():##Start the runs        
        
        
        
        LlmA = Action("MCR-LLM", "fct", HyperspectralSegmentation_MCR_LLM.mcr_llm, LlmT.get())
        AlsA = Action("MCR-ALS", "fct", HyperspectralSegmentation_MCR_ALS.mcr_als, AlsT.get())
        NmfA = Action("NMF", "fct", HyperspectralSegmentation_NMF.nmf, NmfT.get())
        fctList = list()
        fctList.append(LlmA)
        fctList.append(AlsA)
        fctList.append(NmfA)
        
        
        KMeansA = Action("Kmeans", "init", KmeansInit.initialisation, KMeansT.get())
        NFindrA = Action("Nfindr", "init", NFindrInit.initialisation, NFindrT.get())
        MBKmeansA = Action("MBKmeans", "init", MBKmeansInit.initialisation, MBKmeansT.get())
        AtgpA = Action("ATGP", "init", AtgpInit.initialisation, AtgpT.get())
        FippiA = Action("FIPPI", "init", FippiInit.initialisation, FippiT.get())
        PpiA = Action("PPI", "init", PpiInit.initialisation, PpiT.get())
        
        initList = list()
        initList.append(KMeansA)
        initList.append(NFindrA)
        initList.append(MBKmeansA)
        initList.append(AtgpA)
        initList.append(FippiA)
        initList.append(PpiA)
              
        dim = list()
        
         
        if DimT.get():
            print("Redim²")
            dim.append(dim1.get())
            dim.append(dim2.get())
            dim.append(nb_level.get())
            
            
        else:
            dim.append(0)
            dim.append(0)
            dim.append(0)
    
            
            
        
        run(initList, fctList, nb_c.get(), nb_i.get(), filepath, nb_dim.get(), hier.get())
        
    def plotRaw():
        
        x = loadFile(filepath)
        plt.figure()
        dim = nb_dim.get()
        if dim == 3:
            plt.title('Intensity Map')
            plt.imshow(np.log(np.sum(x, axis = 2)))
            plt.show()
            
            plt.figure()
            plt.title('Average Spectra')
            plt.plot(np.sum(np.sum(x,axis = 0), axis = 0))
            plt.show()
            
        elif dim ==2:
            plt.title('Intensity Line')
            plt.plot(np.sum(x, axis = 1))
            plt.show()
            
            plt.figure()
            plt.title('Average Spectra')
            plt.plot(np.sum(x,axis = 0))
            plt.show()
            
            
    def runHier():
        X3 = loadFile(filepath)
        if nb_dim.get() == 3:
            dim1 = X3.shape[0]
            dim2 = X3.shape[1]
            nb_level.set(X3.shape[2])
            nb_pix = dim1*dim2
            
            
        elif nb_dim.get() == 2:
            nb_level.set(X3.shape[1])
            nb_pix = X3.shape[0]


        Xraw = np.reshape(X3, (nb_pix, nb_level.get()))
        
        #avoid errors, if a energy level has 0 counts on all pixels, it causes log(0) and the level is meaningless, so we take it out
        deletedLevels = []
        nb_deleted = 0
        
        for lev in range(nb_level.get()):
            
            if np.sum(Xraw[:,lev-nb_deleted]) <= 0:
                
                deletedLevels.append(lev)
                Xraw = np.delete(Xraw, lev-nb_deleted, axis = 1)
                nb_deleted = nb_deleted + 1
        
        S_hier = h_MCR_LLM.h_mcr_llm( nb_imcr.get(), min_pixels.get(), max_pixels.get(), Max_level.get(), Xraw)
        
        
        for ii in range(nb_deleted):  #Insert deleted spectra back (the spectra was 0 that's why we took it out)
            S_hier = np.insert(S_hier,deletedLevels[ii], np.zeros(nb_c), axis = 1)
        np.save('S_hier.npy', S_hier)
        
        

        pcaselect.computeShow(np.array(S_hier), nb_c.get())
            
        
    def chooseSpectra():
        
        S_hier = np.load('S_hier.npy')
        
        global Sselect
        Sselect = pcaselect.computeSelect(np.array(S_hier), nb_c.get())
            
        
    def saveSpectra():
        Si = []
        
        for i in range(nb_c.get()): 
            Si.append(Sselect[i].selectedSpectra)
        
        Si = np.array(Si)
        np.save('Sselect.npy', Si)
            
    
    def selectFile():
        global filepath
        filepath = askopenfilename(title="Ouvrir un jeu de données",filetypes=[('npy files','.npy'),('dm4 files','.dm4'),('txt files','.txt'),('all files','.*')])
    
    def linkKmeans(self):
        webbrowser.open_new(r"https://www.datascience.com/blog/k-means-clustering")
        
    def linkMBKmeans(self):
        webbrowser.open_new(r"http://scikit-learn.org/stable/modules/clustering.html#mini-batch-kmeans")
                            
    def linkNFindr(self):
        webbrowser.open_new(r"https://ieeexplore.ieee.org/abstract/document/5560827") 
    
    def linkAtgp(self):
        webbrowser.open_new(r"https://ieeexplore.ieee.org/document/6947261") 
        
    def linkFippi(self):
        webbrowser.open_new(r"https://ieeexplore.ieee.org/document/1576691")
    
    def linkPpi(self):
        webbrowser.open_new(r"https://ieeexplore.ieee.org/document/1576691")
    
    def __init__(self, top=None):
        '''This class configures and populates the toplevel window.
           top is the toplevel containing window.'''
        _bgcolor = '#d9d9d9'  # X11 color: 'gray85'
        _fgcolor = '#000000'  # X11 color: 'black'
        _compcolor = '#d9d9d9' # X11 color: 'gray85'
        _ana1color = '#d9d9d9' # X11 color: 'gray85' 
        _ana2color = '#d9d9d9' # X11 color: 'gray85' 
        font10 = "-family {Book Antiqua} -size 14 -weight bold -slant "  \
            "roman -underline 0 -overstrike 0"
        font9 = "-family {Book Antiqua} -size 11 -weight normal -slant"  \
            " roman -underline 0 -overstrike 0"

        top.geometry("695x560+662+164")
        top.title("GUI - Hugo")
        top.configure(background="#d9d9d9")
        top.configure(height="2")
        top.configure(highlightbackground="#d9d9d9")
        top.configure(highlightcolor="black")



        self.menubar = Menu(top,font="TkMenuFont",bg=_bgcolor,fg=_fgcolor)
        top.configure(menu = self.menubar)

        #%% File box
        self.Frame2 = Frame(top)
        self.Frame2.place(relx=0.03, rely=0.03, relheight=0.3, relwidth=0.935)
        self.Frame2.configure(relief=GROOVE)
        self.Frame2.configure(borderwidth="2")
        self.Frame2.configure(relief=GROOVE)
        self.Frame2.configure(background="#ffffff")
        self.Frame2.configure(highlightbackground="#d9d9d9")
        self.Frame2.configure(highlightcolor="black")
        self.Frame2.configure(width=475)
        
        
        
        
        #Sélectionner fichier
        self.Label1_5 = Button(self.Frame2)
        self.Label1_5.place(relx=0.3, rely=0.00, height=31, width=260)
        self.Label1_5.configure(activebackground="#ffffff")
        self.Label1_5.configure(activeforeground="#ffffff")
        self.Label1_5.configure(background="#d9d9d9")
        self.Label1_5.configure(disabledforeground="#a3a3a3")
        self.Label1_5.configure(font=font10)
        self.Label1_5.configure(foreground="#000000")
        self.Label1_5.configure(highlightbackground="#d9d9d9")
        self.Label1_5.configure(highlightcolor="black")
        self.Label1_5.configure(text="Selectionner le fichier")
        self.Label1_5.configure(command = New_Toplevel.selectFile)
        
        
        # Composants
        self.Label1_5 = Label(self.Frame2)
        self.Label1_5.place(relx=0.0, rely=0.3, height=31, width=110)
        self.Label1_5.configure(activebackground="#ffffff")
        self.Label1_5.configure(activeforeground="#ffffff")
        self.Label1_5.configure(background="#ffffff")
        self.Label1_5.configure(disabledforeground="#a3a3a3")
        self.Label1_5.configure(font=font9)
        self.Label1_5.configure(foreground="#000000")
        self.Label1_5.configure(highlightbackground="#d9d9d9")
        self.Label1_5.configure(highlightcolor="black")
        self.Label1_5.configure(text="Composants")
        
        
        self.Spinbox1 = Spinbox(self.Frame2, from_=1.0, to=100.0)
        self.Spinbox1.place(relx=0.2, rely=0.3, relheight=0.15, relwidth=0.179)
        
        self.Spinbox1.configure(activebackground="#d9d9d9")
        self.Spinbox1.configure(background="#d9d9d9")
        self.Spinbox1.configure(buttonbackground="#d9d9d9")
        self.Spinbox1.configure(disabledforeground="#a3a3a3")
        self.Spinbox1.configure(foreground="black")
        self.Spinbox1.configure(from_="1.0")
        self.Spinbox1.configure(highlightbackground="black")
        self.Spinbox1.configure(highlightcolor="black")
        self.Spinbox1.configure(insertbackground="black")
        self.Spinbox1.configure(selectbackground="#c4c4c4")
        self.Spinbox1.configure(selectforeground="black")
        self.Spinbox1.configure(textvariable=nb_c)
        self.Spinbox1.configure(to="100.0")
        
        
        #Dimensions
        self.Label1_9 = Label(self.Frame2)
        self.Label1_9.place(relx=0.0, rely=0.57, height=31, width=110)
        self.Label1_9.configure(activebackground="#ffffff")
        self.Label1_9.configure(activeforeground="#ffffff")
        self.Label1_9.configure(background="#ffffff")
        self.Label1_9.configure(disabledforeground="#a3a3a3")
        self.Label1_9.configure(font=font9)
        self.Label1_9.configure(foreground="#000000")
        self.Label1_9.configure(highlightbackground="#d9d9d9")
        self.Label1_9.configure(highlightcolor="black")
        self.Label1_9.configure(text='''Dimensions''')
        
        
        self.Spinbox3 = Spinbox(self.Frame2, from_=2.0, to=3.0)
        self.Spinbox3.place(relx=0.2, rely=0.6, relheight=0.15, relwidth=0.179)
        
        self.Spinbox3.configure(activebackground="#d9d9d9")
        self.Spinbox3.configure(background="#d9d9d9")
        self.Spinbox3.configure(buttonbackground="#d9d9d9")
        self.Spinbox3.configure(disabledforeground="#a3a3a3")
        self.Spinbox3.configure(foreground="black")
        self.Spinbox3.configure(from_="2.0")
        self.Spinbox3.configure(highlightbackground="black")
        self.Spinbox3.configure(highlightcolor="black")
        self.Spinbox3.configure(insertbackground="black")
        self.Spinbox3.configure(selectbackground="#c4c4c4")
        self.Spinbox3.configure(selectforeground="black")
        self.Spinbox3.configure(textvariable=nb_dim)
        self.Spinbox3.configure(to="3.0")
        self.Spinbox3.configure(width=35)
        
        
        # Plot raw
        self.Button2 = Button(self.Frame2)
        self.Button2.place(relx=0.4, rely=0.4, height=34, width=117)
        self.Button2.configure(activebackground="#d9d9d9")
        self.Button2.configure(activeforeground="#000000")
        self.Button2.configure(background="#d9d9d9")
        self.Button2.configure(disabledforeground="#a3a3a3")
        self.Button2.configure(foreground="#000000")
        self.Button2.configure(highlightbackground="#d9d9d9")
        self.Button2.configure(highlightcolor="black")
        self.Button2.configure(pady="0")
        self.Button2.configure(text='''Plot Raw''')
        self.Button2.configure(width=117)
        self.Button2.configure(command = New_Toplevel.plotRaw)  
        
        
        
        
        
        
        
        #%% hier box
        self.Frame3 = Frame(top)
        self.Frame3.place(relx=0.03, rely=0.375, relheight=0.563, relwidth=0.3)
        self.Frame3.configure(relief=GROOVE)
        self.Frame3.configure(borderwidth="2")
        self.Frame3.configure(relief=GROOVE)
        self.Frame3.configure(background="#ffffff")
        self.Frame3.configure(highlightbackground="#d9d9d9")
        self.Frame3.configure(highlightcolor="black")
        self.Frame3.configure(width=195)
        
        #hier title
        self.Label3 = Label(self.Frame3)
        self.Label3.place(relx=0.0, rely=0.0, height=50, width=200)
        self.Label3.configure(activebackground="#ffffff")
        self.Label3.configure(activeforeground="#ffffff")
        self.Label3.configure(background="#ffffff")
        self.Label3.configure(disabledforeground="#a3a3a3")
        self.Label3.configure(font=font10)
        self.Label3.configure(foreground="#000000")
        self.Label3.configure(highlightbackground="#d9d9d9")
        self.Label3.configure(highlightcolor="black")
        self.Label3.configure(text="Paramètres\nhiéarchique")
        
        
        # Run hllm
        self.Button3 = Button(self.Frame3)
        self.Button3.place(relx=0.14, rely=0.6, height=34, width=130)
        self.Button3.configure(activebackground="#d9d9d9")
        self.Button3.configure(activeforeground="#000000")
        self.Button3.configure(background="#d9d9d9")
        self.Button3.configure(disabledforeground="#a3a3a3")
        self.Button3.configure(foreground="#000000")
        self.Button3.configure(highlightbackground="#d9d9d9")
        self.Button3.configure(highlightcolor="black")
        self.Button3.configure(pady="0")
        self.Button3.configure(text='''1 - Run Hier''')
        self.Button3.configure(width=117)
        self.Button3.configure(command = New_Toplevel.runHier)
        
        
        
        # Choose spectra
        self.Button4 = Button(self.Frame3)
        self.Button4.place(relx=0.14, rely=0.72, height=34, width=130)
        self.Button4.configure(activebackground="#d9d9d9")
        self.Button4.configure(activeforeground="#000000")
        self.Button4.configure(background="#d9d9d9")
        self.Button4.configure(disabledforeground="#a3a3a3")
        self.Button4.configure(foreground="#000000")
        self.Button4.configure(highlightbackground="#d9d9d9")
        self.Button4.configure(highlightcolor="black")
        self.Button4.configure(pady="0")
        self.Button4.configure(text='''2 - Choose Spectra''')
        self.Button4.configure(width=117)
        self.Button4.configure(command = New_Toplevel.chooseSpectra)
        
        
        # Save spectra
        self.Button4 = Button(self.Frame3)
        self.Button4.place(relx=0.14, rely=0.84, height=34, width=130)
        self.Button4.configure(activebackground="#d9d9d9")
        self.Button4.configure(activeforeground="#000000")
        self.Button4.configure(background="#d9d9d9")
        self.Button4.configure(disabledforeground="#a3a3a3")
        self.Button4.configure(foreground="#000000")
        self.Button4.configure(highlightbackground="#d9d9d9")
        self.Button4.configure(highlightcolor="black")
        self.Button4.configure(pady="0")
        self.Button4.configure(text='''3 - Save Spectra''')
        self.Button4.configure(width=117)
        self.Button4.configure(command = New_Toplevel.saveSpectra)
        
        
        
        
        
        # Ittérations hiéarchique
        self.Label1_1 = Label(self.Frame3)
        self.Label1_1.place(relx=0.14, rely=0.17, height=20, width=80)
        self.Label1_1.configure(activebackground="#ffffff")
        self.Label1_1.configure(activeforeground="#ffffff")
        self.Label1_1.configure(background="#ffffff")
        self.Label1_1.configure(disabledforeground="#a3a3a3")
        self.Label1_1.configure(font=font9)
        self.Label1_1.configure(foreground="#000000")
        self.Label1_1.configure(highlightbackground="#d9d9d9")
        self.Label1_1.configure(highlightcolor="black")
        self.Label1_1.configure(text='Itérations')
        

        self.Spinbox5 = Spinbox(self.Frame3, from_=1.0, to=100.0)
        self.Spinbox5.place(relx=0.6, rely=0.17, relheight=0.07, relwidth=0.17)

        self.Spinbox5.configure(activebackground="#d9d9d9")
        self.Spinbox5.configure(background="#d9d9d9")
        self.Spinbox5.configure(buttonbackground="#d9d9d9")
        self.Spinbox5.configure(disabledforeground="#a3a3a3")
        self.Spinbox5.configure(foreground="black")
        self.Spinbox5.configure(from_="1.0")
        self.Spinbox5.configure(highlightbackground="black")
        self.Spinbox5.configure(highlightcolor="black")
        self.Spinbox5.configure(insertbackground="black")
        self.Spinbox5.configure(selectbackground="#c4c4c4")
        self.Spinbox5.configure(selectforeground="black")
        self.Spinbox5.configure(textvariable=nb_imcr)
        self.Spinbox5.configure(width=35)
        
        
        
        # Min Pixels
        self.Label1_2 = Label(self.Frame3)
        self.Label1_2.place(relx=0.14, rely=0.26, height=20, width=80)
        self.Label1_2.configure(activebackground="#ffffff")
        self.Label1_2.configure(activeforeground="#ffffff")
        self.Label1_2.configure(background="#ffffff")
        self.Label1_2.configure(disabledforeground="#a3a3a3")
        self.Label1_2.configure(font=font9)
        self.Label1_2.configure(foreground="#000000")
        self.Label1_2.configure(highlightbackground="#d9d9d9")
        self.Label1_2.configure(highlightcolor="black")
        self.Label1_2.configure(text='Min Pixels')
        

        self.Spinbox6 = Spinbox(self.Frame3, from_=1.0, to=100.0)
        self.Spinbox6.place(relx=0.6, rely=0.26, relheight=0.07, relwidth=0.17)

        self.Spinbox6.configure(activebackground="#d9d9d9")
        self.Spinbox6.configure(background="#d9d9d9")
        self.Spinbox6.configure(buttonbackground="#d9d9d9")
        self.Spinbox6.configure(disabledforeground="#a3a3a3")
        self.Spinbox6.configure(foreground="black")
        self.Spinbox6.configure(from_="1.0")
        self.Spinbox6.configure(highlightbackground="black")
        self.Spinbox6.configure(highlightcolor="black")
        self.Spinbox6.configure(insertbackground="black")
        self.Spinbox6.configure(selectbackground="#c4c4c4")
        self.Spinbox6.configure(selectforeground="black")
        self.Spinbox6.configure(textvariable=min_pixels)
        self.Spinbox6.configure(width=35)
        
        
        
        # Max Pixels
        self.Label1_3 = Label(self.Frame3)
        self.Label1_3.place(relx=0.14, rely=0.35, height=20, width=85)
        self.Label1_3.configure(activebackground="#ffffff")
        self.Label1_3.configure(activeforeground="#ffffff")
        self.Label1_3.configure(background="#ffffff")
        self.Label1_3.configure(disabledforeground="#a3a3a3")
        self.Label1_3.configure(font=font9)
        self.Label1_3.configure(foreground="#000000")
        self.Label1_3.configure(highlightbackground="#d9d9d9")
        self.Label1_3.configure(highlightcolor="black")
        self.Label1_3.configure(text='Max Pixels')
        

        self.Spinbox7 = Spinbox(self.Frame3, from_=1.0, to=100.0)
        self.Spinbox7.place(relx=0.6, rely=0.35, relheight=0.07, relwidth=0.17)

        self.Spinbox7.configure(activebackground="#d9d9d9")
        self.Spinbox7.configure(background="#d9d9d9")
        self.Spinbox7.configure(buttonbackground="#d9d9d9")
        self.Spinbox7.configure(disabledforeground="#a3a3a3")
        self.Spinbox7.configure(foreground="black")
        self.Spinbox7.configure(from_="1.0")
        self.Spinbox7.configure(highlightbackground="black")
        self.Spinbox7.configure(highlightcolor="black")
        self.Spinbox7.configure(insertbackground="black")
        self.Spinbox7.configure(selectbackground="#c4c4c4")
        self.Spinbox7.configure(selectforeground="black")
        self.Spinbox7.configure(textvariable=max_pixels)
        self.Spinbox7.configure(width=35)
        
        
        # Max Levels
        self.Label2 = Label(self.Frame3)
        self.Label2.place(relx=0.14, rely=0.45, height=20, width=90)
        self.Label2.configure(activebackground="#ffffff")
        self.Label2.configure(activeforeground="#ffffff")
        self.Label2.configure(background="#ffffff")
        self.Label2.configure(disabledforeground="#a3a3a3")
        self.Label2.configure(font=font9)
        self.Label2.configure(foreground="#000000")
        self.Label2.configure(highlightbackground="#d9d9d9")
        self.Label2.configure(highlightcolor="black")
        self.Label2.configure(text='Max Levels')
        

        self.Spinbox7 = Spinbox(self.Frame3, from_=1.0, to=100.0)
        self.Spinbox7.place(relx=0.6, rely=0.45, relheight=0.07, relwidth=0.17)

        self.Spinbox7.configure(activebackground="#d9d9d9")
        self.Spinbox7.configure(background="#d9d9d9")
        self.Spinbox7.configure(buttonbackground="#d9d9d9")
        self.Spinbox7.configure(disabledforeground="#a3a3a3")
        self.Spinbox7.configure(foreground="black")
        self.Spinbox7.configure(from_="1.0")
        self.Spinbox7.configure(highlightbackground="black")
        self.Spinbox7.configure(highlightcolor="black")
        self.Spinbox7.configure(insertbackground="black")
        self.Spinbox7.configure(selectbackground="#c4c4c4")
        self.Spinbox7.configure(selectforeground="black")
        self.Spinbox7.configure(textvariable=Max_level)
        self.Spinbox7.configure(width=35)
       





        #%% init box
        self.Frame1 = Frame(top)
        self.Frame1.place(relx=0.37, rely=0.375, relheight=0.563, relwidth=0.281)
        self.Frame1.configure(relief=GROOVE)
        self.Frame1.configure(borderwidth="2")
        self.Frame1.configure(relief=GROOVE)
        self.Frame1.configure(background="#ffffff")
        self.Frame1.configure(highlightbackground="#d9d9d9")
        self.Frame1.configure(highlightcolor="black")
        self.Frame1.configure(width=195)
        
        
        #init title
        self.Label1_7 = Label(self.Frame1)
        self.Label1_7.place(relx=0.15, rely=0.0, height=20, width=140)
        self.Label1_7.configure(activebackground="#ffffff")
        self.Label1_7.configure(activeforeground="#ffffff")
        self.Label1_7.configure(background="#ffffff")
        self.Label1_7.configure(disabledforeground="#a3a3a3")
        self.Label1_7.configure(font=font10)
        self.Label1_7.configure(foreground="#000000")
        self.Label1_7.configure(highlightbackground="#d9d9d9")
        self.Label1_7.configure(highlightcolor="black")
        self.Label1_7.configure(text="Initialisation")
        
        
        
        #Hier
        self.Checkbutton1_5 = Checkbutton(self.Frame1)
        self.Checkbutton1_5.place(relx=0.205, rely=0.065, relheight=0.111, relwidth=0.569)
        self.Checkbutton1_5.configure(activebackground="#d9d9d9")
        self.Checkbutton1_5.configure(activeforeground="#000000")
        self.Checkbutton1_5.configure(background="#d9d9d9")
        self.Checkbutton1_5.configure(disabledforeground="#a3a3a3")
        self.Checkbutton1_5.configure(foreground="#000000")
        self.Checkbutton1_5.configure(highlightbackground="#d9d9d9")
        self.Checkbutton1_5.configure(highlightcolor="black")
        self.Checkbutton1_5.configure(indicatoron="0")
        self.Checkbutton1_5.configure(justify=LEFT)
        self.Checkbutton1_5.configure(text="hiéarchique")
        self.Checkbutton1_5.configure(variable=hier)
        
        
        
        
        #Kmeans
        self.Checkbutton1_6 = Checkbutton(self.Frame1)
        self.Checkbutton1_6.place(relx=0.205, rely=0.19, relheight=0.111, relwidth=0.569)
        self.Checkbutton1_6.configure(activebackground="#d9d9d9")
        self.Checkbutton1_6.configure(activeforeground="#000000")
        self.Checkbutton1_6.configure(background="#d9d9d9")
        self.Checkbutton1_6.configure(disabledforeground="#a3a3a3")
        self.Checkbutton1_6.configure(foreground="#000000")
        self.Checkbutton1_6.configure(highlightbackground="#d9d9d9")
        self.Checkbutton1_6.configure(highlightcolor="black")
        self.Checkbutton1_6.configure(indicatoron="0")
        self.Checkbutton1_6.configure(justify=LEFT)
        self.Checkbutton1_6.configure(text="Kmeans")
        self.Checkbutton1_6.configure(variable=KMeansT)
        
        self.helpKmeans = Label(self.Frame1, text="?", fg="blue", cursor="hand2")
        self.helpKmeans.pack()
        self.helpKmeans.place(relx = 0.850, rely = 0.210)
        self.helpKmeans.bind("<Button-1>", New_Toplevel.linkKmeans)
        
        
        #NFinder
        self.Checkbutton1_2 = Checkbutton(self.Frame1)
        self.Checkbutton1_2.place(relx=0.205, rely=0.317, relheight=0.111, relwidth=0.569)
        self.Checkbutton1_2.configure(activebackground="#d9d9d9")
        self.Checkbutton1_2.configure(activeforeground="#000000")
        self.Checkbutton1_2.configure(background="#d9d9d9")
        self.Checkbutton1_2.configure(disabledforeground="#a3a3a3")
        self.Checkbutton1_2.configure(foreground="#000000")
        self.Checkbutton1_2.configure(highlightbackground="#d9d9d9")
        self.Checkbutton1_2.configure(highlightcolor="black")
        self.Checkbutton1_2.configure(indicatoron="0")
        self.Checkbutton1_2.configure(justify=LEFT)
        self.Checkbutton1_2.configure(text="NFindr")
        self.Checkbutton1_2.configure(variable=NFindrT)
        
        self.helpNFindr = Label(self.Frame1, text="?", fg="blue", cursor="hand2")
        self.helpNFindr.pack()
        self.helpNFindr.place(relx = 0.850, rely = 0.337)
        self.helpNFindr.bind("<Button-1>", New_Toplevel.linkNFindr)
        
        
        
        #MBKmeans
        self.Checkbutton1_3 = Checkbutton(self.Frame1)
        self.Checkbutton1_3.place(relx=0.205, rely=0.444, relheight=0.111, relwidth=0.569)
        self.Checkbutton1_3.configure(activebackground="#d9d9d9")
        self.Checkbutton1_3.configure(activeforeground="#000000")
        self.Checkbutton1_3.configure(background="#d9d9d9")
        self.Checkbutton1_3.configure(disabledforeground="#a3a3a3")
        self.Checkbutton1_3.configure(foreground="#000000")
        self.Checkbutton1_3.configure(highlightbackground="#d9d9d9")
        self.Checkbutton1_3.configure(highlightcolor="black")
        self.Checkbutton1_3.configure(indicatoron="0")
        self.Checkbutton1_3.configure(justify=LEFT)
        self.Checkbutton1_3.configure(text="MBKmeans")
        self.Checkbutton1_3.configure(variable=MBKmeansT)
        
        self.helpMBKmeans = Label(self.Frame1, text="?", fg="blue", cursor="hand2")
        self.helpMBKmeans.pack()
        self.helpMBKmeans.place(relx = 0.850, rely = 0.464)
        self.helpMBKmeans.bind("<Button-1>", New_Toplevel.linkMBKmeans)


        #ATGP
        self.Checkbutton1_4 = Checkbutton(self.Frame1)
        self.Checkbutton1_4.place(relx=0.205, rely=0.571, relheight=0.111, relwidth=0.569)
        self.Checkbutton1_4.configure(activebackground="#d9d9d9")
        self.Checkbutton1_4.configure(activeforeground="#000000")
        self.Checkbutton1_4.configure(background="#d9d9d9")
        self.Checkbutton1_4.configure(disabledforeground="#a3a3a3")
        self.Checkbutton1_4.configure(foreground="#000000")
        self.Checkbutton1_4.configure(highlightbackground="#d9d9d9")
        self.Checkbutton1_4.configure(highlightcolor="black")
        self.Checkbutton1_4.configure(indicatoron="0")
        self.Checkbutton1_4.configure(justify=LEFT)
        self.Checkbutton1_4.configure(text="ATGP")
        self.Checkbutton1_4.configure(variable=AtgpT)
        
        self.helpAtgp = Label(self.Frame1, text="?", fg="blue", cursor="hand2")
        self.helpAtgp.pack()
        self.helpAtgp.place(relx = 0.850, rely = 0.591)
        self.helpAtgp.bind("<Button-1>", New_Toplevel.linkAtgp)
        
        
        #FIPPI
        self.Checkbutton1_1 = Checkbutton(self.Frame1)
        self.Checkbutton1_1.place(relx=0.205, rely=0.698, relheight=0.111, relwidth=0.569)
        self.Checkbutton1_1.configure(activebackground="#d9d9d9")
        self.Checkbutton1_1.configure(activeforeground="#000000")
        self.Checkbutton1_1.configure(background="#d9d9d9")
        self.Checkbutton1_1.configure(disabledforeground="#a3a3a3")
        self.Checkbutton1_1.configure(foreground="#000000")
        self.Checkbutton1_1.configure(highlightbackground="#d9d9d9")
        self.Checkbutton1_1.configure(highlightcolor="black")
        self.Checkbutton1_1.configure(indicatoron="0")
        self.Checkbutton1_1.configure(justify=LEFT)
        self.Checkbutton1_1.configure(text="FIPPI")
        self.Checkbutton1_1.configure(variable=FippiT)
        
        self.helpFippi = Label(self.Frame1, text="?", fg="blue", cursor="hand2")
        self.helpFippi.pack()
        self.helpFippi.place(relx = 0.850, rely = 0.718)
        self.helpFippi.bind("<Button-1>", New_Toplevel.linkFippi)
        
        
        #PPI
        self.Checkbutton1_2 = Checkbutton(self.Frame1)
        self.Checkbutton1_2.place(relx=0.205, rely=0.825, relheight=0.111, relwidth=0.569)
        self.Checkbutton1_2.configure(activebackground="#d9d9d9")
        self.Checkbutton1_2.configure(activeforeground="#000000")
        self.Checkbutton1_2.configure(background="#d9d9d9")
        self.Checkbutton1_2.configure(disabledforeground="#a3a3a3")
        self.Checkbutton1_2.configure(foreground="#000000")
        self.Checkbutton1_2.configure(highlightbackground="#d9d9d9")
        self.Checkbutton1_2.configure(highlightcolor="black")
        self.Checkbutton1_2.configure(indicatoron="0")
        self.Checkbutton1_2.configure(justify=LEFT)
        self.Checkbutton1_2.configure(text="PPI")
        self.Checkbutton1_2.configure(variable=PpiT)

        self.helpPpi = Label(self.Frame1, text="?", fg="blue", cursor="hand2")
        self.helpPpi.pack()
        self.helpPpi.place(relx = 0.850, rely = 0.845)
        self.helpPpi.bind("<Button-1>", New_Toplevel.linkPpi)
    





        #%% Functions box
        self.Frame1_8 = Frame(top)
        self.Frame1_8.place(relx=0.685, rely=0.375, relheight=0.563, relwidth=0.281)
        self.Frame1_8.configure(relief=GROOVE)
        self.Frame1_8.configure(borderwidth="2")
        self.Frame1_8.configure(relief=GROOVE)
        self.Frame1_8.configure(background="#ffffff")
        self.Frame1_8.configure(highlightbackground="#d9d9d9")
        self.Frame1_8.configure(highlightcolor="black")
        self.Frame1_8.configure(width=195)
        
        
        #Titre fonctions
        self.Label1_8 = Label(self.Frame1_8)
        self.Label1_8.place(relx=0.205, rely=0.063, height=31, width=110)
        self.Label1_8.configure(activebackground="#ffffff")
        self.Label1_8.configure(activeforeground="#ffffff")
        self.Label1_8.configure(background="#ffffff")
        self.Label1_8.configure(disabledforeground="#a3a3a3")
        self.Label1_8.configure(font=font10)
        self.Label1_8.configure(foreground="#000000")
        self.Label1_8.configure(highlightbackground="#d9d9d9")
        self.Label1_8.configure(highlightcolor="black")
        self.Label1_8.configure(text="Fonctions")
        
        
        #MCR_LLM
        self.Checkbutton1_7 = Checkbutton(self.Frame1_8)
        self.Checkbutton1_7.place(relx=0.205, rely=0.19, relheight=0.111, relwidth=0.569)
        self.Checkbutton1_7.configure(activebackground="#d9d9d9")
        self.Checkbutton1_7.configure(activeforeground="#000000")
        self.Checkbutton1_7.configure(background="#d9d9d9")
        self.Checkbutton1_7.configure(disabledforeground="#a3a3a3")
        self.Checkbutton1_7.configure(foreground="#000000")
        self.Checkbutton1_7.configure(highlightbackground="#d9d9d9")
        self.Checkbutton1_7.configure(highlightcolor="black")
        self.Checkbutton1_7.configure(indicatoron="0")
        self.Checkbutton1_7.configure(justify=LEFT)
        self.Checkbutton1_7.configure(text="MCR-LLM")
        self.Checkbutton1_7.configure(variable=LlmT)



        #MCR-ALS
        self.Checkbutton1_3 = Checkbutton(self.Frame1_8)
        self.Checkbutton1_3.place(relx=0.205, rely=0.317, relheight=0.111, relwidth=0.569)
        self.Checkbutton1_3.configure(activebackground="#d9d9d9")
        self.Checkbutton1_3.configure(activeforeground="#000000")
        self.Checkbutton1_3.configure(background="#d9d9d9")
        self.Checkbutton1_3.configure(disabledforeground="#a3a3a3")
        self.Checkbutton1_3.configure(foreground="#000000")
        self.Checkbutton1_3.configure(highlightbackground="#d9d9d9")
        self.Checkbutton1_3.configure(highlightcolor="black")
        self.Checkbutton1_3.configure(indicatoron="0")
        self.Checkbutton1_3.configure(justify=LEFT)
        self.Checkbutton1_3.configure(text="MCR-ALS")
        self.Checkbutton1_3.configure(variable=AlsT)
        
        
        
        #NMF
        self.Checkbutton1_3 = Checkbutton(self.Frame1_8)
        self.Checkbutton1_3.place(relx=0.205, rely=0.444, relheight=0.111
                , relwidth=0.569)
        self.Checkbutton1_3.configure(activebackground="#d9d9d9")
        self.Checkbutton1_3.configure(activeforeground="#000000")
        self.Checkbutton1_3.configure(background="#d9d9d9")
        self.Checkbutton1_3.configure(disabledforeground="#a3a3a3")
        self.Checkbutton1_3.configure(foreground="#000000")
        self.Checkbutton1_3.configure(highlightbackground="#d9d9d9")
        self.Checkbutton1_3.configure(highlightcolor="black")
        self.Checkbutton1_3.configure(indicatoron="0")
        self.Checkbutton1_3.configure(justify=LEFT)
        self.Checkbutton1_3.configure(text="NMF")
        self.Checkbutton1_3.configure(variable=NmfT)






        #Ittérations
        self.Label1_6 = Label(self.Frame1_8)
        self.Label1_6.place(relx=0.051, rely=0.7, height=31, width=110)
        self.Label1_6.configure(activebackground="#ffffff")
        self.Label1_6.configure(activeforeground="#ffffff")
        self.Label1_6.configure(background="#ffffff")
        self.Label1_6.configure(disabledforeground="#a3a3a3")
        self.Label1_6.configure(font=font9)
        self.Label1_6.configure(foreground="#000000")
        self.Label1_6.configure(highlightbackground="#d9d9d9")
        self.Label1_6.configure(highlightcolor="black")
        self.Label1_6.configure(text='''Itérations''')
        

        self.Spinbox2 = Spinbox(self.Frame1_8, from_=1.0, to=100.0)
        self.Spinbox2.place(relx=0.667, rely=0.72, relheight=0.06, relwidth=0.179)

        self.Spinbox2.configure(activebackground="#d9d9d9")
        self.Spinbox2.configure(background="#d9d9d9")
        self.Spinbox2.configure(buttonbackground="#d9d9d9")
        self.Spinbox2.configure(disabledforeground="#a3a3a3")
        self.Spinbox2.configure(foreground="black")
        self.Spinbox2.configure(from_="1.0")
        self.Spinbox2.configure(highlightbackground="black")
        self.Spinbox2.configure(highlightcolor="black")
        self.Spinbox2.configure(insertbackground="black")
        self.Spinbox2.configure(selectbackground="#c4c4c4")
        self.Spinbox2.configure(selectforeground="black")
        self.Spinbox2.configure(textvariable=nb_i)
        self.Spinbox2.configure(width=35)
        
        
        
    
        
        
        
        #GO!
        self.Button1 = Button(self.Frame1_8)
        self.Button1.place(relx=0.205, rely=0.825, height=34, width=117)
        self.Button1.configure(activebackground="#d9d9d9")
        self.Button1.configure(activeforeground="#000000")
        self.Button1.configure(background="#d9d9d9")
        self.Button1.configure(disabledforeground="#a3a3a3")
        self.Button1.configure(foreground="#000000")
        self.Button1.configure(highlightbackground="#d9d9d9")
        self.Button1.configure(highlightcolor="black")
        self.Button1.configure(pady="0")
        self.Button1.configure(text='''Go !''')
        self.Button1.configure(width=117)
        self.Button1.configure(command = New_Toplevel.returnValues)
          


        


        
        






        
if __name__ == '__main__':
    vp_start_gui()






#! /usr/bin/env python
#  -*- coding: utf-8 -*-
#
# Support module generated by PAGE version 4.17
# In conjunction with Tcl version 8.6
#    Sep 20, 2018 12:17:49 PM EDT  platform: Windows NT

import sys

try:
    from Tkinter import *
except ImportError:
    from tkinter import *

try:
    import ttk
    py3 = False
except ImportError:
    import tkinter.ttk as ttk
    py3 = True

def set_Tk_var():
    global KMeansB
    KMeansB = IntVar()
    global NFindrB
    NFindrB = IntVar()
    global MBKmeansB
    MBKmeansB = IntVar()
    global ATGPB
    ATGPB = IntVar()
    global FIPPIB
    FIPPIB = IntVar()
    global PPIB
    PPIB = IntVar()
    global LLMB
    LLMB = IntVar()
    global ALSB
    ALSB = IntVar()
    global nb_i
    nb_i = IntVar()
    global nb_c
    nb_c = IntVar()

def init(top, gui, *args, **kwargs):
    global w, top_level, root
    w = gui
    top_level = top
    root = top

def destroy_window():
    # Function which closes the window.
    global top_level
    top_level.destroy()
    top_level = None

if __name__ == '__main__':
    import GUI
    GUI.vp_start_gui()





# -*- coding: utf-8 -*-
"""
Created on Thu Aug 15 13:41:53 2019

@auteur : Louis-Philippe Baillargeon
"""
#%% User Input

#analysis parameters - mcrllm 
nb_i = 10                        # Number of iterations in mcr_llm


#%% code
from SI_File_Toolbox import plotCompare, plotSpectraGroup
import matplotlib.pyplot as plt
import numpy as np
from fct_MCRLLM import HyperspectralSegmentation_MCR_LLM    # Import the algorithm to use

#Load spectrum
Si = np.zeros((nb_c,nb_level))

for i in range(nb_c): 
    Si[i,:] = np.copy(Sselect[i].selectedSpectra)
    

# MCR_LLM
print('MCR-LLM')
C, S = HyperspectralSegmentation_MCR_LLM.mcr_llm(Xraw, nb_c, Si, nb_iter = nb_i)


for i in range(nb_deleted):
    S = np.insert(S,deletedLevels[i], np.zeros(nb_c), axis = 1)

# Show the results

#rearrange data
if dim == 3:
    C3 = np.reshape(C, (dim1,dim2, nb_c))
    C = np.copy(C3)
    plotCompare(S, Emin, Emax, C, pas = 1, log = False)
    
else:
    plt.figure()
    plt.plot(C)
    
plotSpectraGroup(S, [1,2], Emin = Emin, Emax = Emax)